import React__default, { useState, useRef, useEffect, createElement } from 'react';
import { WidthProvider, Responsive } from 'react-grid-layout';
import 'react-apexcharts';
import axios from 'axios';
import { Button } from 'primereact/button';
import { OverlayPanel } from 'primereact/overlaypanel';
import { ProgressSpinner } from 'primereact/progressspinner';
import ReactFC from 'react-fusioncharts';
import FusionCharts from 'fusioncharts';
import Charts from 'fusioncharts/fusioncharts.charts';
import FusionTheme from 'fusioncharts/themes/fusioncharts.theme.fusion';
import useResizeObserver from 'use-resize-observer';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var Tools = /*#__PURE__*/function () {
  function Tools() {}

  Tools.GetLogitudeURL = function GetLogitudeURL() {
    var logitude_url = location.href.replace('index.html', '');

    if (location.href.indexOf('localhost') > -1) {
      logitude_url = 'http://localhost:9996';
    } else {
      var urlArr = location.href.split("/index.html");
      var url = urlArr[0];
      url = url.replace(url.substring(url.lastIndexOf('/'), url.length), "");
      logitude_url = url;
    }

    return logitude_url;
  };

  Tools.Map = function Map(from, to) {
    if (!from) return;
    if (!to) to = {};
    var keys = Object.keys(from);

    for (var _i = 0, _keys = keys; _i < _keys.length; _i++) {
      var k = _keys[_i];

      if (from[k]) {
        to[k] = from[k];
      }
    }
  };

  return Tools;
}();

var ApiServices = /*#__PURE__*/function () {
  function ApiServices() {
    this._apiUrl = Tools.GetLogitudeURL();
  }

  var _proto = ApiServices.prototype;

  _proto.getByFilters = function getByFilters(api, filters) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    apiURL = this.ConcatFiltersToURL(filters, apiURL);
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.get = function get(api) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.post = function post(api, date) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.post(apiURL, date, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.getTokenFromStorage = function getTokenFromStorage() {
    return window.localStorage.getItem("token") || '';
  };

  _proto.ConcatFiltersToURL = function ConcatFiltersToURL(filters, urlparameters) {
    var mykeys = Object.keys(filters);
    var addtionalFiltersValues = null;

    for (var i in mykeys) {
      var propName = mykeys[i];
      var propValue = filters[propName];
      var ignoreFilter = propName.indexOf("Operator") > 0 && propValue == "Equals" || propName == "AdditionalFilters";

      if (urlparameters != "?") {
        urlparameters = urlparameters.concat('&');
      }

      if (!ignoreFilter) {
        propValue = propValue ? encodeURIComponent(propValue) : '';
        urlparameters = urlparameters.concat(propName.concat('=').concat(propValue));
      }

      if (propName == "AdditionalFilters" && propValue.length > 0) {
        addtionalFiltersValues = JSON.stringify(propValue);
      }
    }

    if (addtionalFiltersValues) {
      urlparameters = urlparameters.concat("&AdditionalFilters=").concat(addtionalFiltersValues);
    }

    return urlparameters;
  };

  return ApiServices;
}();

var DashboardAnalyticsService = /*#__PURE__*/function () {
  function DashboardAnalyticsService() {
    this.controller = 'DashboardAnalytics';
    this._ApiServices = new ApiServices();
  }

  var _proto = DashboardAnalyticsService.prototype;

  _proto.getData = function getData(widget) {
    return this._ApiServices.post("/api/" + this.controller + "/PostGetDataAnalytic", widget);
  };

  _proto.getKpiData = function getKpiData(widget) {
    return this._ApiServices.post("/api/" + this.controller + "/PostGetKpiData", widget);
  };

  return DashboardAnalyticsService;
}();

var KpiChart = function KpiChart(props) {
  var _useState = useState(false),
      dataLoaded = _useState[0],
      setDataLoaded = _useState[1];

  var _useState2 = useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var widget = useRef();
  var widgetRef = useRef();
  var hasDataError = useRef(false);

  var _useState3 = useState(),
      data = _useState3[0],
      setData = _useState3[1];

  var _useState4 = useState(),
      title = _useState4[0],
      setTitle = _useState4[1];

  useEffect(function () {
    widget.current = props.customChartProps.widget;
    onRefresh();
  }, []);

  var onRefresh = function onRefresh() {
    var _props$customChartPro;

    (_props$customChartPro = props.customChartProps.dataBinding) === null || _props$customChartPro === void 0 ? void 0 : _props$customChartPro.onEditWidget.subscribe(function (e) {
      var _widget$current;

      if (e.key == ((_widget$current = widget.current) === null || _widget$current === void 0 ? void 0 : _widget$current.key)) {
        setDataLoaded(false);
        Tools.Map(e, widget.current);
        setTimeout(function () {
          RefreshData();
        }, 500);
      }
    });
  };

  useEffect(function () {
    widgetRef.current = props.customChartProps.widgetRef;
    setTimeout(function () {
      RefreshData();
    }, 500);
  }, []);
  useEffect(function () {
    widgetRef.current = props.customChartProps.widgetRef;
  }, [props.customChartProps.widgetRef]);

  var RefreshData = function RefreshData() {
    var _props$customChartPro2, _props$customChartPro3;

    setTitle(props === null || props === void 0 ? void 0 : (_props$customChartPro2 = props.customChartProps) === null || _props$customChartPro2 === void 0 ? void 0 : (_props$customChartPro3 = _props$customChartPro2.widget) === null || _props$customChartPro3 === void 0 ? void 0 : _props$customChartPro3.Title);
    var dashboardAnalyticsService = new DashboardAnalyticsService();

    var postWidget = _extends({}, widget.current);

    postWidget.onChange = undefined;
    dashboardAnalyticsService.getKpiData(postWidget).then(function (result) {
      setData(result.data);
      setDataLoaded(true);
    }, function (error) {
      var _error$response, _error$response$data, _error$response2, _error$response2$data;

      console.log('error', error);
      if (error !== null && error !== void 0 && (_error$response = error.response) !== null && _error$response !== void 0 && (_error$response$data = _error$response.data) !== null && _error$response$data !== void 0 && _error$response$data.ErrorMessage) setError(error === null || error === void 0 ? void 0 : (_error$response2 = error.response) === null || _error$response2 === void 0 ? void 0 : (_error$response2$data = _error$response2.data) === null || _error$response2$data === void 0 ? void 0 : _error$response2$data.ErrorMessage);else setError(error.message);
      setDataLoaded(true);
    });
  };

  var kpiClick = function kpiClick() {
    var _props$customChartPro4, _props$customChartPro5, _props$customChartPro6, _props$customChartPro7, _props$customChartPro8;

    var measureFieldId;
    if ((_props$customChartPro4 = props.customChartProps) !== null && _props$customChartPro4 !== void 0 && (_props$customChartPro5 = _props$customChartPro4.widgetRef) !== null && _props$customChartPro5 !== void 0 && _props$customChartPro5.WidgetMeasures) measureFieldId = (_props$customChartPro6 = props.customChartProps) === null || _props$customChartPro6 === void 0 ? void 0 : (_props$customChartPro7 = _props$customChartPro6.widgetRef) === null || _props$customChartPro7 === void 0 ? void 0 : (_props$customChartPro8 = _props$customChartPro7.WidgetMeasures[0]) === null || _props$customChartPro8 === void 0 ? void 0 : _props$customChartPro8.MeasureFieldId;
    props.customChartProps.onSelectDataPoint({
      MeasureFieldId: measureFieldId,
      Widget: props.customChartProps.widget
    });
  };

  return !dataLoaded ? React__default.createElement("div", {
    className: 'dl-full-hight dl-flex-content-center spinner-custome'
  }, React__default.createElement(ProgressSpinner, {
    style: {
      width: '60px',
      height: '60px'
    },
    strokeWidth: "4",
    animationDuration: "2s"
  })) : !error ? React__default.createElement("div", {
    className: "kpIcontainer",
    onClick: kpiClick
  }, React__default.createElement("div", {
    className: "kpIHeader"
  }, title), React__default.createElement("div", null, data === null || data === void 0 ? void 0 : data.Value, " ")) : React__default.createElement("div", {
    className: "dl-flex-content-center dl-full-hight "
  }, React__default.createElement("div", {
    className: "dl-tooltip"
  }, React__default.createElement("img", {
    width: 100,
    src: "https://www.seekpng.com/png/full/334-3345964_error-icon-png.png"
  }), React__default.createElement("span", {
    className: "dl-tooltiptext"
  }, error)));
};

var CustomChart = function CustomChart(props) {
  var project = function project() {
    var _props$widget;

    switch ((_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.TypeCode) {
      case "kpi":
        return React__default.createElement(KpiChart, {
          customChartProps: props
        });

      default:
        return React__default.createElement("div", null, "Invalid Type");
    }
  };

  return React__default.createElement("div", {
    style: {
      height: '100%'
    }
  }, project());
};

function BuildFusionChartObject(seriesMeasures, props) {
  var _props$widget;

  handelNullLabels(seriesMeasures);
  var defaultChart = getDefaultChartobject(seriesMeasures, props);

  switch ((_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.TypeCode) {
    case 'bar':
      return getBarObject(seriesMeasures, defaultChart);

    case 'line':
      return getLineObject(seriesMeasures, defaultChart);

    case 'pie':
      return getPieObject(seriesMeasures, defaultChart);

    case 'donut':
      return getDonutObject(seriesMeasures, defaultChart);

    default:
      return defaultChart;
  }
}

function handelNullLabels(seriesMeasures) {
  seriesMeasures.forEach(function (element) {
    element.SeriesMeasureVulues.forEach(function (value) {
      if (!value.Label || value.Label == '') value.Label = 'Not defined';
    });
  });
}

function getBarObject(seriesMeasures, chart) {
  chart.type = "scrollbar2d";
  return chart;
}

function getLineObject(seriesMeasures, chart) {
  chart.type = "scrollline2d";
  return chart;
}

function getDonutObject(seriesMeasures, chart) {
  chart.type = "doughnut2d";
  return chart;
}

function getPieObject(seriesMeasures, chart) {
  chart.type = "pie2d";
  return chart;
}

function getDefaultChartobject(seriesMeasures, props) {
  var chart = {};
  chart.type = "column2d";
  chart.width = "100%";
  chart.height = "80%";
  chart.dataFormat = "json";
  buildChartDataSource(chart, props, seriesMeasures);
  return chart;
}

function buildChartDataSource(chart, props, seriesMeasures) {
  var _props$widget2, _props$widget3, _props$widget4, _props$widget5;

  if (!seriesMeasures || !seriesMeasures[0]) return;
  var chartinfo = {
    theme: "fusion",
    scrollHeight: "5",
    scrollWidth: "5",
    scrollPadding: "8",
    flatScrollBars: "1",
    enableSlicing: "0",
    showLegend: ((_props$widget2 = props.widget) === null || _props$widget2 === void 0 ? void 0 : _props$widget2.TypeCode) == "bar" || ((_props$widget3 = props.widget) === null || _props$widget3 === void 0 ? void 0 : _props$widget3.TypeCode) == "line" ? "1" : "0"
  };

  if (((_props$widget4 = props.widget) === null || _props$widget4 === void 0 ? void 0 : _props$widget4.TypeCode) == "bar" || ((_props$widget5 = props.widget) === null || _props$widget5 === void 0 ? void 0 : _props$widget5.TypeCode) == "line") {
    chart.dataSource = {
      chart: chartinfo,
      categories: buildCategories(seriesMeasures),
      dataset: buildDataSet(seriesMeasures)
    };
    return;
  }

  chart.dataSource = {
    chart: chartinfo,
    data: buildDataSource(seriesMeasures)
  };
}

function buildDataSource(values) {
  var data = [];
  if (!values || !values[0]) return data;
  data = values[0].SeriesMeasureVulues.map(function (e) {
    return {
      value: e.Value,
      label: e.Label,
      id: {
        GroupById: e.GroupById,
        MeasureFieldId: values[0].MeasureFieldId
      }
    };
  });
  return data;
}

function buildDataSet(seriesMeasures) {
  var dataSet = [];
  seriesMeasures.forEach(function (seriesMeasure) {
    var datas = seriesMeasure.SeriesMeasureVulues.map(function (e) {
      return {
        value: e.Value,
        id: {
          GroupById: e.GroupById,
          MeasureFieldId: seriesMeasure.MeasureFieldId
        }
      };
    });
    dataSet.push({
      data: datas,
      seriesname: seriesMeasure.Name
    });
  });
  return dataSet;
}

function buildCategories(seriesMeasures) {
  var categories = seriesMeasures[0].SeriesMeasureVulues.map(function (e) {
    return {
      label: e.Label
    };
  });
  var result = [];
  result.push({
    category: categories
  });
  return result;
}

ReactFC.fcRoot(FusionCharts, Charts, FusionTheme);

var FusionChart = function FusionChart(props) {
  var _useState = useState(false),
      dataLoaded = _useState[0],
      setDataLoaded = _useState[1];

  var _useState2 = useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var widget = useRef();
  var widgetRef = useRef();

  var _useState3 = useState({}),
      args = _useState3[0],
      setArgs = _useState3[1];

  var _useState4 = useState({}),
      fChart = _useState4[0],
      setFchart = _useState4[1];

  var entered = useRef(false);
  var id = (Math.random() + 1).toString(36).substring(7);
  useEffect(function () {
    widget.current = props.widget;
    onRefresh();
  }, []);

  var onRefresh = function onRefresh() {
    var _props$dataBinding;

    (_props$dataBinding = props.dataBinding) === null || _props$dataBinding === void 0 ? void 0 : _props$dataBinding.onEditWidget.subscribe(function (e) {
      var _widget$current;

      if (e.key == ((_widget$current = widget.current) === null || _widget$current === void 0 ? void 0 : _widget$current.key)) {
        setDataLoaded(false);
        Tools.Map(e, widget.current);
        setTimeout(function () {
          RefreshData();
        }, 500);
      }
    });
  };

  useEffect(function () {
    widgetRef.current = props.widgetRef;
    setTimeout(function () {
      RefreshData();
    }, 500);
  }, []);
  useEffect(function () {
    widgetRef.current = props.widgetRef;
  }, [props.widgetRef]);

  var RefreshData = function RefreshData() {
    var dashboardAnalyticsService = new DashboardAnalyticsService();

    var postWidget = _extends({}, widget.current);

    postWidget.onChange = undefined;
    dashboardAnalyticsService.getData(postWidget).then(function (result) {
      var chart = BuildFusionChartObject(result.data, props);
      setArgs(chart);
      setDataLoaded(true);
    }, function (error) {
      var _error$response, _error$response$data, _error$response2, _error$response2$data;

      console.log('error', error);
      if (error !== null && error !== void 0 && (_error$response = error.response) !== null && _error$response !== void 0 && (_error$response$data = _error$response.data) !== null && _error$response$data !== void 0 && _error$response$data.ErrorMessage) setError(error === null || error === void 0 ? void 0 : (_error$response2 = error.response) === null || _error$response2 === void 0 ? void 0 : (_error$response2$data = _error$response2.data) === null || _error$response2$data === void 0 ? void 0 : _error$response2$data.ErrorMessage);else setError(error.message);
      setDataLoaded(true);
    });
  };

  var dataplotClick = function dataplotClick(eventObj, dataObj) {
    props.onSelectDataPoint({
      GroupById: dataObj.id.groupbyid,
      MeasureFieldId: dataObj.id.measurefieldid,
      Widget: widget.current
    });
  };

  var renderComplete = function renderComplete(chart) {
    setFchart(chart);
  };

  var _useResizeObserver = useResizeObserver({
    onResize: function onResize(_ref) {
      var width = _ref.width,
          height = _ref.height;

      if (entered.current == false) {
        entered.current = true;
        return;
      }

      fChart.resizeTo(width, height);
    }
  }),
      ref = _useResizeObserver.ref;

  return !dataLoaded ? React__default.createElement("div", {
    className: 'dl-full-hight dl-flex-content-center spinner-custome'
  }, React__default.createElement(ProgressSpinner, {
    style: {
      width: '60px',
      height: '60px'
    },
    strokeWidth: "4",
    animationDuration: "2s"
  })) : !error ? React__default.createElement("div", {
    className: 'db-fc-container',
    ref: ref,
    id: id
  }, React__default.createElement(ReactFC, Object.assign({}, args, {
    "fcEvent-dataplotClick": dataplotClick,
    onRender: renderComplete
  }))) : React__default.createElement("div", {
    className: "dl-flex-content-center dl-full-hight "
  }, React__default.createElement("div", {
    className: "dl-tooltip"
  }, React__default.createElement("img", {
    width: 100,
    src: "https://www.seekpng.com/png/full/334-3345964_error-icon-png.png"
  }), React__default.createElement("span", {
    className: "dl-tooltiptext"
  }, error)));
};

var WidgetCard = function WidgetCard(props, state) {
  var _props$widget, _props$widget2, _props$widget4;

  var moreBtnToggle = useRef(null);

  var editWidget = function editWidget() {
    var _moreBtnToggle$curren;

    (_moreBtnToggle$curren = moreBtnToggle.current) === null || _moreBtnToggle$curren === void 0 ? void 0 : _moreBtnToggle$curren.hide();
    props.editBtnClicked(props.widget);
  };

  return React__default.createElement("div", {
    className: "panel",
    key: props.el.i,
    style: {
      cursor: props.isInEditMode ? 'move' : 'default'
    }
  }, React__default.createElement("header", null, React__default.createElement("h1", null, (props === null || props === void 0 ? void 0 : (_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.TypeCode) == "kpi" ? null : (_props$widget2 = props.widget) === null || _props$widget2 === void 0 ? void 0 : _props$widget2.Title), props.isInEditMode ? React__default.createElement(Button, {
    icon: "pi pi-ellipsis-v",
    className: "p-button-rounded p-button-text",
    onClick: function onClick(e) {
      var _moreBtnToggle$curren2;

      return (_moreBtnToggle$curren2 = moreBtnToggle.current) === null || _moreBtnToggle$curren2 === void 0 ? void 0 : _moreBtnToggle$curren2.toggle(e);
    },
    style: {
      color: "#292D30"
    }
  }) : null, React__default.createElement(OverlayPanel, {
    ref: moreBtnToggle,
    className: "buttons-overlay"
  }, React__default.createElement("div", {
    className: "buttons-list"
  }, React__default.createElement("div", {
    onClick: editWidget
  }, " Edit "), React__default.createElement("div", {
    onClick: function onClick() {
      var _props$widget3;

      return props.deleteBtnClicked((_props$widget3 = props.widget) === null || _props$widget3 === void 0 ? void 0 : _props$widget3.key);
    }
  }, "Remove")))), React__default.createElement("div", {
    className: "dl-line"
  }), React__default.createElement("div", {
    className: "dl-dashboard-widget"
  }, (props === null || props === void 0 ? void 0 : (_props$widget4 = props.widget) === null || _props$widget4 === void 0 ? void 0 : _props$widget4.TypeCode) == "kpi" ? React__default.createElement(CustomChart, {
    dataBinding: props.dataBinding,
    widget: props.widget,
    widgetRef: props.widgetRef,
    onSelectDataPoint: props.onSelectDataPoint
  }) : React__default.createElement(FusionChart, {
    dataBinding: props.dataBinding,
    widget: props.widget,
    widgetRef: props.widgetRef,
    onSelectDataPoint: props.onSelectDataPoint
  })));
};

function deepClone(obj) {
  return JSON.parse(JSON.stringify(obj));
}

var ResponsiveReactGridLayout = WidthProvider(Responsive);

var DashboardDesigner = function DashboardDesigner(props) {
  var array12 = Array.from({
    length: 12
  }).fill(null);
  var minimumPlaceholderRowsCount = 12;

  var _useState = useState({
    lg: []
  }),
      layouts = _useState[0],
      setLayouts = _useState[1];

  var _useState2 = useState(Array.from({
    length: minimumPlaceholderRowsCount
  }).fill(null)),
      placeholderRowsArray = _useState2[0],
      setplaceholderRowsArray = _useState2[1];

  var _useState3 = useState(undefined),
      dateFilter = _useState3[0];

  var _useState4 = useState(false),
      isInEditMode = _useState4[0],
      setisInEditMode = _useState4[1];

  var widgetsDictionaryRef = useRef({});

  var _useState5 = useState({
    lg: []
  }),
      widgets = _useState5[0],
      setWidgets = _useState5[1];

  var gridLayoutComponent = useRef(null);
  var entered = useRef(false);
  useEffect(function () {
    FillLayout(props.Widgetlayouts);
  }, [props.Widgetlayouts]);

  var FillLayout = function FillLayout(dashboardLayouts) {
    var clone = deepClone(dashboardLayouts);
    var layout = createLayout(clone);
    FillWidgetDictionary(clone);
    setWidgets(clone);
    setLayouts(layout);
    UpdatePlaceholderDimensions(layout);
  };

  var FillWidgetDictionary = function FillWidgetDictionary(clone) {
    for (var _iterator = _createForOfIteratorHelperLoose(clone.lg), _step; !(_step = _iterator()).done;) {
      var item = _step.value;
      widgetsDictionaryRef.current[item.key] = item;
    }
  };

  var createLayout = function createLayout(dashboardLayouts) {
    var layout = {
      lg: []
    };
    dashboardLayouts.lg.map(function (w) {
      return w.Layout;
    }).forEach(function (e) {
      layout.lg.push(e);
    });
    return layout;
  };

  useEffect(function () {
    setisInEditMode(props.editMode);
  }, [props.editMode]);

  function onLayoutChange(layout, changedLayouts) {
    UpdateWidget(changedLayouts);
    setLayouts(changedLayouts);
    UpdatePlaceholderDimensions(changedLayouts);

    if (entered.current == false) {
      entered.current = true;
      return;
    }

    props.onLayoutChange(changedLayouts);
  }

  function UpdateWidget(changedLayouts) {
    for (var _iterator2 = _createForOfIteratorHelperLoose(changedLayouts.lg), _step2; !(_step2 = _iterator2()).done;) {
      var item = _step2.value;

      if (widgetsDictionaryRef.current[item.i]) {
        widgetsDictionaryRef.current[item.i].Layout = item;
      }
    }
  }

  function deletePanel(id) {
    var newLayouts = {
      lg: layouts.lg.filter(function (e) {
        return e.i != id;
      })
    };
    setLayouts(newLayouts);
    var newWidgets = {
      lg: widgets.lg.filter(function (e) {
        return e.key != id;
      })
    };
    FillWidgetDictionary(newWidgets);
    setWidgets(newWidgets);
    props.onLayoutChange(newLayouts);
  }

  function editWidget(widget) {
    widget.ChangeSetOp = 'Update';
    props.openEditWidget(widget);
  }

  function UpdatePlaceholderDimensions(layouts) {
    if (!layouts) return;
    var max = minimumPlaceholderRowsCount;

    for (var _iterator3 = _createForOfIteratorHelperLoose(layouts['lg']), _step3; !(_step3 = _iterator3()).done;) {
      var layout = _step3.value;
      if (layout.y + layout.h > max) max = layout.y + layout.h;
    }

    var newPlaceholderRows = max + 2;
    newPlaceholderRows = newPlaceholderRows < minimumPlaceholderRowsCount ? minimumPlaceholderRowsCount : newPlaceholderRows;
    setplaceholderRowsArray(Array.from({
      length: newPlaceholderRows
    }).fill(null));
  }

  return React__default.createElement("div", {
    className: "dl-full-hight-scroll"
  }, React__default.createElement("div", {
    className: "dl-box"
  }, React__default.createElement("div", {
    className: "dl-row dl-content"
  }, React__default.createElement("div", {
    className: "dl-grid-container"
  }, React__default.createElement("div", {
    className: "dl-grid dl-grid--bordered"
  }, isInEditMode ? placeholderRowsArray.map(function (e, i) {
    return array12.map(function (e, i) {
      return React__default.createElement("div", {
        key: i,
        style: {
          height: layoutGridProps.rowHeight
        }
      });
    });
  }) : null), React__default.createElement(ResponsiveReactGridLayout, Object.assign({
    ref: gridLayoutComponent
  }, layoutGridProps, {
    layouts: layouts,
    compactType: "vertical",
    isDraggable: isInEditMode,
    isResizable: isInEditMode,
    onWidthChange: function onWidthChange() {},
    onLayoutChange: onLayoutChange
  }), widgets.lg.map(function (widget) {
    var _widget$Layout, _widget$Layout2;

    return React__default.createElement("div", {
      key: (_widget$Layout = widget.Layout) === null || _widget$Layout === void 0 ? void 0 : _widget$Layout.i
    }, React__default.createElement(WidgetCard, {
      isInEditMode: isInEditMode,
      key: (_widget$Layout2 = widget.Layout) === null || _widget$Layout2 === void 0 ? void 0 : _widget$Layout2.i,
      widget: widget,
      widgetRef: widgetsDictionaryRef.current[widget.key],
      el: widget,
      dataBinding: props.dataBinding,
      dateFilter: dateFilter,
      editBtnClicked: editWidget,
      deleteBtnClicked: deletePanel,
      onSelectDataPoint: props.onSelectDataPoint
    }));
  }))))));
};

var layoutGridProps = {
  rowHeight: 50,
  className: "layout",
  cols: {
    lg: 12,
    md: 6,
    sm: 2,
    xs: 1,
    xxs: 1
  },
  useCSSTransforms: true
};

var Dashboard = function Dashboard(props) {
  var _props$token;

  var Widgetlayouts = useRef({
    lg: []
  });

  var _useState = useState({
    lg: []
  }),
      widgetlayoutsState = _useState[0],
      setWidgetlayoutsState = _useState[1];

  var _useState2 = useState(false),
      isInEditMode = _useState2[0],
      setIsInEditMode = _useState2[1];

  useEffect(function () {
    props.dataBinding.onGetLayouts.subscribe(function (layouts) {
      Widgetlayouts.current = layouts;
      setWidgetlayoutsState(deepClone(Widgetlayouts.current));
    });
    props.dataBinding.isOnEditLayout.subscribe(function (e) {
      setIsInEditMode(e);
    });
    props.dataBinding.onAddWidget.subscribe(function (w) {
      Widgetlayouts.current.lg.push(w);
      setWidgetlayoutsState(deepClone(Widgetlayouts.current));
    });
  }, []);
  if ((props === null || props === void 0 ? void 0 : (_props$token = props.token) === null || _props$token === void 0 ? void 0 : _props$token.length) > 0) localStorage.setItem("token", props === null || props === void 0 ? void 0 : props.token);

  var updateWidgets = function updateWidgets(layouts) {
    var layoutsDic = {};
    Object.keys(layouts).forEach(function (sizeType) {
      if (layouts[sizeType].length > 0) {
        layouts[sizeType].map(function (layout) {
          layoutsDic[layout.i] = layout;
        });
        return;
      }
    });
    var newWidgetlayouts = [];
    Widgetlayouts.current.lg.forEach(function (widget) {
      if (layoutsDic[widget.key]) {
        widget.StartPotistion = layoutsDic[widget.key].x + "," + layoutsDic[widget.key].y;
        widget.EndPosition = layoutsDic[widget.key].w + "," + layoutsDic[widget.key].h;
        widget.Layout = layoutsDic[widget.key];
        newWidgetlayouts.push(widget);
      }
    });
    Widgetlayouts.current = {
      lg: newWidgetlayouts
    };
    props.onChangeLayouts(Widgetlayouts.current);
  };

  return createElement("div", {
    className: 'dl-full-hight'
  }, createElement("div", {
    className: 'dl-dashboard-body'
  }, createElement(DashboardDesigner, {
    onSelectDataPoint: props.onSelectDataPoint,
    Widgetlayouts: widgetlayoutsState,
    dataBinding: props.dataBinding,
    editMode: isInEditMode,
    onLayoutChange: updateWidgets,
    openEditWidget: function openEditWidget(widget) {
      return props.openEditWidget(widget);
    }
  })));
};

export default Dashboard;
//# sourceMappingURL=index.modern.js.map
